Welcome to Django Stories’s documentation! — Django Stories v0.5 documentation

Django Stories v0.5 documentation

# Welcome to Django Stories’s documentation!

- Table of Contents
- index
  modules
  next

# Welcome to Django Stories’s documentation!

Contents:

- Installation
- Settings
  - STORY_STATUS_CHOICES
  - STORY_DEFAULT_STATUS
  - STORY_PUBLISHED_STATUS
  - STORY_ORIGIN_CHOICES
  - STORY_DEFAULT_ORIGIN
  - STORY_INCLUDE_PRINT
  - STORY_RELATION_MODELS
  - STORY_PAGINATION
  - STORY_P_PER_PAGE
  - STORY_ORPHANS
- Pagination
  - Settings that affect pagination
  - Using pagination in templates
- Integration with Other Django Applications
  - Integrating with Django Reversion
  - Integrating with Django TinyMCE
- User Manual
  - Entering a Story
  - Revisions
- Reference Manual
  - Models

# Indices and tables

- Index
- Module Index
- Search Page